# library(devtools)
# install_github("aykutfirat/cldr")
# library(cldr)

filelist = list.files(path="./data/raw/CrisisLexT26_data_raw", pattern="\\.csv",
                 full.names=TRUE, ignore.case=TRUE)

for (f in filelist) {
  # f <- filelist[1]
  # read file
  table <- read.csv(f, header = TRUE, colClasses = "character", stringsAsFactors = FALSE)
  table$Information.Source <- NULL
  table$Information.Type   <- NULL
  # table$Tweet.ID           <- NULL
  names(table) <- c("tweet.id", "tweet", "label")

  # reduplicate
  table <- subset(table, !duplicated(tweet))

  # factor labels
  table$label <- factor(table$label)
  levels(table$label) <- list(
    `0` = c("Not applicable", "Not related"),
    `1` = c("Related and informative", "Related - but not informative")
  )

  # select only english records
  table$lang <- sapply(table$tweet, function(txt) {
    # txt <- table$tweet[254]
    txt <- tolower(txt)
    txt <- gsub("(@[a-z0-9_]+)|(#[a-z0-9_]+)", "", txt)
    txt <- gsub("(?:https?://|www.|ftp.)[-a-z0-9+&@#/%=~_|$?!:,.]*[a-z0-9+&@#/%=~_|$]", "", txt)
    lang <- cldr::detectLanguage(txt, isPlainText=TRUE, hintLanguageCode=cldr::Languages$ENGLISH)
    return(lang$detectedLanguage)
  })
  table <- table[table$lang == "ENGLISH", ]
  table$lang <- NULL

  # write ready file
  write.csv(
    table,
    file = gsub("(.*)-.*", "./data/ready/T26_\\1.csv", basename(f)),
    quote = c(1, 2),
    row.names = FALSE,
    fileEncoding = "UTF-8"
  )
}


### dataset summary
filelist = list.files(path="./data/ready", pattern="T26_.*\\.csv",
                      full.names=TRUE, ignore.case=TRUE)
data <- do.call("rbind", lapply(filelist, function(x) {
  table <- read.csv(x, header = TRUE)
  table$file <- gsub("^\\./data/ready/(.*)\\.csv$", "\\1", x)
  return (table)
}))

topic.off <- nrow(data[data$label == 0, ])
topic.on  <- nrow(data[data$label == 1, ])
cat(sprintf("\n\n-- CrisisLexT26 --"))
cat(sprintf("\noff: %4d, on: %4d, balance: %4.1f%% (on-topic ratio)",
  topic.off, topic.on, topic.on/(topic.off+topic.on)*100
))

datasets <- gsub("\\./data/ready/(.*)\\.csv", "\\1", filelist)
for (x in datasets) {
  set <- data[data$file == x, ]
  topic.off <- nrow(set[set$label == 0, ])
  topic.on  <- nrow(set[set$label == 1, ])
  cat(sprintf("\n\n-- %s --", x))
  cat(sprintf("\noff: %4d, on: %4d, balance: %4.1f%% (on-topic ratio)",
    topic.off, topic.on, topic.on/(topic.off+topic.on)*100
  ))
}


rm(data, set, table, datasets, f, filelist, topic.on, topic.off, x)

### Compare 'cldr' and 'textcat' -----------------------------------------------
#
# for(i in 1:30) {
#   txt <- table$tweet[i]
#   txt <- tolower(txt)
#   txt <- gsub("(@[a-z0-9_]+)|(#[a-z0-9_]+)", "", txt)
#   txt <- gsub("(?:https?://|www.|ftp.)[-a-z0-9+&@#/%=~_|$?!:,.]*[a-z0-9+&@#/%=~_|$]", "", txt)
#   lang1 <- cldr::detectLanguage(txt, isPlainText=TRUE)
#   lang1 <- sprintf("%.10s", lang1$detectedLanguage)
#   lang2 <- textcat::textcat(txt)
#   lang2 <- sprintf("%.10s", lang2)
#   cat(sprintf("[%-10s][%-10s] %.90s\n",
#     lang1,
#     lang2, #table$label[i],
#     txt
#   ))
# }
