# first data retrieve
sql.data <- "
WITH places AS (
SELECT name
  FROM places
     , (%1$s) AS disaster
 WHERE ST_Contains(disaster_geom, geom)
   AND type NOT IN ('hamlet', 'neighbourhood', 'locality', 'state', 'country')
 ORDER BY population DESC NULLS LAST
),

tweets_disaster AS (
SELECT lower(unnest(hashtags)) AS hashtag
  FROM tweets
     , (%1$s) AS disaster
 WHERE hashtags IS NOT NULL
   AND ST_Intersects(tweets.geom, disaster.disaster_geom)
   AND created_at BETWEEN '%2$s UTC' AND '%3$s UTC'

 UNION ALL

SELECT lower(unnest(hashtags)) AS hashtag
  FROM tweets
     , (SELECT name FROM places LIMIT %4$d) AS places
  WHERE hashtags IS NOT NULL
   AND to_tsvector('english', tweets.message) @@ plainto_tsquery('english', places.name)
   AND created_at BETWEEN '%2$s UTC' AND '%3$s UTC'
)

SELECT hashtag  AS tag
     , count(*) AS freq
  FROM tweets_disaster
 GROUP BY hashtag
 ORDER BY freq DESC;"

# filter 1 :: tags used before the disaster
sql.filter.1 <- "
WITH places AS (
SELECT name
  FROM places
     , (%1$s) AS disaster
 WHERE ST_Contains(disaster_geom, geom)
   AND type NOT IN ('hamlet', 'neighbourhood', 'locality', 'state', 'country')
 ORDER BY population DESC NULLS LAST
),

hashtags_before AS (
SELECT lower(unnest(hashtags)) AS hashtag
  FROM tweets
     , (%1$s) AS disaster
 WHERE ST_Intersects(tweets.geom, disaster.disaster_geom)
   AND created_at BETWEEN (TIMESTAMP '%2$s UTC' - INTERVAL '11 days')
                      AND (TIMESTAMP '%2$s UTC' - INTERVAL ' 1 days')

 UNION

SELECT lower(unnest(hashtags)) AS hashtag
  FROM tweets
     , (SELECT name FROM places LIMIT %3$d) AS places
 WHERE to_tsvector('english', tweets.message) @@ plainto_tsquery('english', places.name)
   AND created_at BETWEEN (TIMESTAMP '%2$s UTC' - INTERVAL '11 days')
                      AND (TIMESTAMP '%2$s UTC' - INTERVAL ' 1 days')
)

SELECT hashtag
  FROM hashtags_before
 GROUP BY hashtag;"

# filter 2 :: take 200 messages for every hashtag
sql.filter.2 <- "
	SELECT '%1$s'::text AS tag
	     , message
	     , hashtags
	  FROM tweets
   WHERE hashtags && ARRAY['%1$s']::citext[]
     AND created_at BETWEEN '%2$s UTC' AND '%3$s UTC'
	 LIMIT 200"
